@@ -39,12 +39,24 @@ iterable_types = (list, tuple)
 
 
 class RQLFilterClass:
+    """Base class for filter classes."""
+
     MODEL = None
+    """The model this filter is for."""
+
     FILTERS = None
+    """A list or tuple of filters definitions."""
+
     EXTENDED_SEARCH_ORM_ROUTES = tuple()
+
     DISTINCT = False
+    """If True, a `SELECT DISTINCT` will always be executed."""
+
     SELECT = False
+    """If True, this FilterClass supports the ``select`` operator."""
+
     OPENAPI_SPECIFICATION = RQLFilterClassSpecification
+    """Class for OpenAPI specifications generation."""
 
     def __init__(self, queryset, instance=None):
         self.queryset = queryset
